import os

from django import http, urls, views
from django.conf import settings
from django.contrib.auth.decorators import login_required


class NginxAccelRedirectView(views.View):
    location = ''

    @classmethod
    def get_url_path(cls, location: str, **kwargs):
        return urls.path(
            os.path.join(location, '<path:path>'), login_required(cls.as_view(location=location)), **kwargs)

    @classmethod
    def get_proxy_url_path(cls, **kwargs):
        return cls.get_url_path(settings.CHANNEL_TASKS.proxy_route, **kwargs)

    def get(self, request, path, *args, **kwargs):
        response = http.HttpResponse()
        del response['Content-Type']  # TODO: Why this line?
        response['X-Accel-Redirect'] = os.path.join('/internal', self.location, path)
        return response


class NginxFileView(NginxAccelRedirectView):
    def get(self, request, path, *args, **kwargs):
        response = super().get(request, path, *args, **kwargs)
        response['Content-Disposition'] = f'attachment; filename="{path}"'
        return response



import configparser
import os
import pkg_resources


class SettingsIni:
    def __init__(self):
        self.package_name = os.getenv('CHANNEL_TASKS_MAIN_MODULE', 'django_tasks')
        self.ini_rel_path = os.getenv('CHANNEL_TASKS_INI_REL_PATH', 'settings/channel-task-defaults.ini')
        self.ini = configparser.ConfigParser()
        self.ini.read(pkg_resources.resource_filename(self.package_name, self.ini_rel_path))

    @property
    def allowed_hosts(self):
        section, key = 'security', 'allowed-hosts'
        return ([line.strip() for line in self.ini[section][key].splitlines()]
                if self.ini.has_option(section, key) else ['localhost'])

    @property
    def proxy_route(self):
        section, key = 'security', 'proxy-route'
        return self.ini[section][key].strip() if self.ini.has_option(section, key) else ''

    @property
    def expose_doctask_api(self):
        section, key = 'asgi', 'expose-doctask-api'
        return self.ini[section].getboolean(key, False) if self.ini.has_section(section) else False
